from discord.ext import commands

bot = commands.Bot(command_prefix='x')
bot.load_extension("cog")
bot.load_extension("co2")
bot.load_extension("dch")

bot.run("NzI5Njg3Mzg3MTMwNjkxNjY1.XwMkVg.R0QHzj2aVYE_75A-G9JQpxU18tY")